==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/pad_proxies_group.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QObject>
#include <vector>

// Forward declaration
namespace Wdg
{
class Pad_Proxies_Column;
}

namespace Wdg
{

/// @brief Pad_Proxies_Group
///
class Pad_Proxies_Group : public QObject
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Pad_Proxies_Group ( QObject * parent_n = nullptr );

  virtual ~Pad_Proxies_Group ();

  // -- Pad

  /// @brief The pad object
  /// Gets set by the pad and shouldn't be set manually
  QObject *
  pad () const
  {
    return _pad;
  }

  void
  set_pad ( QObject * pad_n );

  // -- Group index

  /// @brief The group index
  /// Gets set by the sliders pad and shouldn't be set manually
  unsigned int
  group_index () const
  {
    return _group_index;
  }

  void
  set_group_index ( unsigned int idx_n );

  // -- Group name

  const QString &
  group_name () const
  {
    return _group_name;
  }

  void
  set_group_name ( const QString & name_n );

  // -- Tool tip

  const QString &
  tool_tip () const
  {
    return _tool_tip;
  }

  void
  set_tool_tip ( const QString & tip_n );

  // -- Style id

  unsigned int
  style_id () const
  {
    return _style_id;
  }

  void
  set_style_id ( unsigned int style_id_n );

  // -- Proxies columns

  ::std::size_t
  num_columns () const
  {
    return _columns.size ();
  }

  void
  append_column ( ::Wdg::Pad_Proxies_Column * column_n );

  void
  clear_columns ();

  ::Wdg::Pad_Proxies_Column *
  column ( ::std::size_t idx_n ) const
  {
    return _columns[ idx_n ];
  }

  // -- Statistics

  unsigned int
  num_sliders () const
  {
    return _num_sliders;
  }

  unsigned int
  num_switches () const
  {
    return _num_switches;
  }

  // Focus

  unsigned char
  focus_column () const
  {
    return _focus_column;
  }

  unsigned char
  focus_row () const
  {
    return _focus_row;
  }

  bool
  has_focus () const
  {
    return _has_focus;
  }

  /// @return true when the focus was taken - false when already has focus or
  /// invalid column
  bool
  take_focus ( unsigned int column_n, unsigned int row_n );

  // Protected methods
  protected:
  bool
  event ( QEvent * event_n ) override;

  // Private attributes
  private:
  QObject * _pad;
  unsigned int _group_index;
  unsigned int _style_id;

  ::std::vector< ::Wdg::Pad_Proxies_Column * > _columns;

  QString _group_name;
  QString _tool_tip;

  unsigned int _num_sliders;
  unsigned int _num_switches;
  unsigned char _focus_column;
  unsigned char _focus_row;
  bool _has_focus;
};

} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/pad_proxies_group.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QObject>
#include <vector>

// Forward declaration
namespace Wdg
{
class Pad_Proxies_Column;
}

namespace Wdg
{

/// @brief Pad_Proxies_Group
///
class Pad_Proxies_Group : public QObject
{
  Q_OBJECT

  public:
  // -- Construction

  Pad_Proxies_Group ( QObject * parent_n = nullptr );

  virtual ~Pad_Proxies_Group ();

  // -- Pad

  /// @brief The pad object
  /// Gets set by the pad and shouldn't be set manually
  QObject *
  pad () const
  {
    return _pad;
  }

  void
  set_pad ( QObject * pad_n );

  // -- Group index

  /// @brief The group index
  /// Gets set by the sliders pad and shouldn't be set manually
  unsigned int
  group_index () const
  {
    return _group_index;
  }

  void
  set_group_index ( unsigned int idx_n );

  // -- Group name

  const QString &
  group_name () const
  {
    return _group_name;
  }

  void
  set_group_name ( const QString & name_n );

  // -- Tool tip

  const QString &
  tool_tip () const
  {
    return _tool_tip;
  }

  void
  set_tool_tip ( const QString & tip_n );

  // -- Style id

  unsigned int
  style_id () const
  {
    return _style_id;
  }

  void
  set_style_id ( unsigned int style_id_n );

  // -- Proxies columns

  std::size_t
  num_columns () const
  {
    return _columns.size ();
  }

  void
  append_column ( Wdg::Pad_Proxies_Column * column_n );

  void
  clear_columns ();

  Wdg::Pad_Proxies_Column *
  column ( std::size_t idx_n ) const
  {
    return _columns[ idx_n ];
  }

  // -- Statistics

  unsigned int
  num_sliders () const
  {
    return _num_sliders;
  }

  unsigned int
  num_switches () const
  {
    return _num_switches;
  }

  // Focus

  unsigned char
  focus_column () const
  {
    return _focus_column;
  }

  unsigned char
  focus_row () const
  {
    return _focus_row;
  }

  bool
  has_focus () const
  {
    return _has_focus;
  }

  /// @return true when the focus was taken - false when already has focus or
  /// invalid column
  bool
  take_focus ( unsigned int column_n, unsigned int row_n );

  protected:
  // -- Protected methods

  bool
  event ( QEvent * event_n ) override;

  private:
  // -- Attributes
  QObject * _pad;
  unsigned int _group_index;
  unsigned int _style_id;

  std::vector< Wdg::Pad_Proxies_Column * > _columns;

  QString _group_name;
  QString _tool_tip;

  unsigned int _num_sliders;
  unsigned int _num_switches;
  unsigned char _focus_column;
  unsigned char _focus_row;
  bool _has_focus;
};

} // namespace Wdg
